@@ -151,6 +151,13 @@ void PackageKitNotifier::checkOfflineUpdates()
                                          QStringLiteral("discoverabstractnotifier"));
                 }
             });
+
+            // No matter what happened, clean up the results file if it still exists
+            // because at this point, there's nothing anyone can do with it
+            if (QFile::exists(QStringLiteral(PK_OFFLINE_RESULTS_FILENAME))) {
+                qDebug() << "Removed offline results file";
+                PackageKit::Daemon::global()->offline()->clearResults();
+            }
         });
 
         notification->sendEvent();
@@ -266,6 +273,13 @@ void PackageKitNotifier::refreshDatabase()
         return;
     }
 
+    for (const auto &t : m_transactions) {
+        auto role = t->role();
+        if (role == PackageKit::Transaction::RoleUpdatePackages || role == PackageKit::Transaction::RoleUpgradeSystem) {
+            return;
+        }
+    }
+
     if (!m_refresher) {
         m_refresher = PackageKit::Daemon::refreshCache(false);
         connect(m_refresher.data(), &PackageKit::Transaction::finished, this, &PackageKitNotifier::recheckSystemUpdateNeeded);
