@@ -148,7 +148,7 @@ int AbstractResourcesBackend::fetchingUpdatesProgress() const
     return isFetching() ? 42 : 100;
 }
 
-HelpfulError *AbstractResourcesBackend::explainDysfunction() const
+InlineMessage *AbstractResourcesBackend::explainDysfunction() const
 {
-    return new HelpfulError(QStringLiteral("network-disconnect"), i18n("Please verify Internet connectivity"));
+    return new InlineMessage(InlineMessage::Error, QStringLiteral("network-disconnect"), i18n("Please verify Internet connectivity"));
 }
