@@ -41,22 +41,26 @@ void NotifierItem::setupNotifierItem()
         if (m_notifier.needsReboot()) {
             m_notifier.reboot();
         } else {
-            m_notifier.showDiscoverUpdates();
+            m_notifier.showDiscoverUpdates(m_item->providedToken());
         }
     });
 
     QMenu *menu = new QMenu;
     connect(m_item, &QObject::destroyed, menu, &QObject::deleteLater);
-    auto discoverAction = menu->addAction(QIcon::fromTheme(QStringLiteral("plasmadiscover")), i18n("Open Discover..."));
-    connect(discoverAction, &QAction::triggered, &m_notifier, &DiscoverNotifier::showDiscover);
+    auto discoverAction = menu->addAction(QIcon::fromTheme(QStringLiteral("plasmadiscover")), i18n("Open Discover…"));
+    connect(discoverAction, &QAction::triggered, &m_notifier, [this] {
+        m_notifier.showDiscover(m_item->providedToken());
+    });
 
-    auto updatesAction = menu->addAction(QIcon::fromTheme(QStringLiteral("system-software-update")), i18n("See Updates..."));
-    connect(updatesAction, &QAction::triggered, &m_notifier, &DiscoverNotifier::showDiscoverUpdates);
+    auto updatesAction = menu->addAction(QIcon::fromTheme(QStringLiteral("system-software-update")), i18n("See Updates…"));
+    connect(updatesAction, &QAction::triggered, &m_notifier, [this] {
+        m_notifier.showDiscoverUpdates(m_item->providedToken());
+    });
 
-    auto refreshAction = menu->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Refresh..."));
+    auto refreshAction = menu->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Refresh…"));
     connect(refreshAction, &QAction::triggered, &m_notifier, &DiscoverNotifier::recheckSystemUpdateNeeded);
 
-    auto f = [menu, this]() {
+    auto f = [this]() {
         m_item->setTitle(i18n("Restart to apply installed updates"));
         m_item->setToolTipTitle(i18n("Click to restart the device"));
         m_item->setIconByName(QStringLiteral("view-refresh"));
